@@ -731,6 +731,20 @@ ut3+b2Xvzq8yzmHMFtLIJ6Afu1jJpqD82BUAFcvi5vhnP8M7b974R18WCOpgNQvXDI+2/8ZINeU=
 -----END CERTIFICATE-----');
         $r = $x509->saveX509($r);
         $r = $x509->loadX509($r);
-        $this->assertSame($r['tbsCertificate']['extensions'][5]['extnValue']['excludedSubtrees'][1]['base']['iPAddress'], ['0.0.0.0', '0.0.0.0']);
+        $this->assertSame($r['tbsCertificate']['extensions'][5]['extnValue']['excludedSubtrees'][1]['base']['iPAddress'], array('0.0.0.0', '0.0.0.0'));
+    }
+
+    /**
+     * @group github1456
+     */
+    public function testRandomString()
+    {
+        $a = 'da7e705569d4196cd49cf3b3d92cd435ca34ccbe';
+        $a = pack('H*', $a);
+
+        $x509 = new File_X509();
+        $r = $x509->loadX509($a);
+
+        $this->assertFalse($r);
     }
 }
