@@ -1,13 +1,13 @@
 <?php
 /**
  * @author    Andreas Fischer <bantu@phpbb.com>
- * @copyright MMXIII Andreas Fischer
+ * @copyright 2013 Andreas Fischer
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
 class Unit_Math_BigInteger_InternalTest extends Unit_Math_BigInteger_TestCase
 {
-    static public function setUpBeforeClass()
+    public static function setUpBeforeClass()
     {
         parent::setUpBeforeClass();
 
